@@ -1517,6 +1517,167 @@ multiply_monster (y, x, cr_index, monptr)
   return FALSE;
 }
 
+struct pos_t
+{
+  int x;
+  int y;
+};
+
+void push (struct pos_t **queue, int *count, int y, int x)
+{
+  struct pos_t pos;
+  pos.y = y;
+  pos.x = x;
+  *queue = realloc (*queue, ((*count) + 1) * sizeof (struct pos_t));
+  (*queue)[*count] = pos;
+  (*count)++;
+}
+
+void pop (struct pos_t **queue, int *count, int *y, int *x)
+{
+  (*count)--;
+  *y = (*queue)[*count].y;
+  *x = (*queue)[*count].x;
+}
+
+static int
+get_can_go_thru_walls (int monptr)
+{
+  monster_type *m_ptr = &m_list[monptr];
+  creature_type *r_ptr = &c_list[m_ptr->mptr];
+  return r_ptr->cmove & CM_PHASE;
+}
+
+static int
+get_can_open_doors (int monptr)
+{
+  monster_type *m_ptr = &m_list[monptr];
+  creature_type *r_ptr = &c_list[m_ptr->mptr];
+  return r_ptr->cmove & CM_OPEN_DOOR;
+}
+
+static int
+get_can_eat_others (int monptr)
+{
+  monster_type *m_ptr = &m_list[monptr];
+  creature_type *r_ptr = &c_list[m_ptr->mptr];
+  return r_ptr->cmove & CM_EATS_OTHER;
+}
+
+//how many moves to get from src to dest?  return non-zero when possible.
+//use 1 for a normal tile, 2 for a door
+static int
+get_tile_weight (int monptr, int src_y, int src_x, int dest_y, int dest_x)
+{
+  cave_type *c_ptr = &cave[dest_y][dest_x];
+  inven_type *t_ptr = &t_list[c_ptr->tptr];
+  if (c_ptr->cptr > 1 && get_can_eat_others (monptr))
+    return 2;
+  if (c_ptr->fval >= MIN_CLOSED_SPACE && get_can_go_thru_walls (monptr))
+    return 1;
+  if (c_ptr->fval <= MAX_OPEN_SPACE && get_can_open_doors (monptr) && 
+      t_ptr->tval == TV_CLOSED_DOOR)
+    return 2;
+  return 1;
+}
+
+//can we get from src to dest? return non-zero when possible.
+//updates the node map
+static int
+calc_moves (int *nodes, int monptr, int src_y, int src_x, int dest_y, int dest_x)
+{
+  int d = (dest_y * cur_width) + dest_x;
+  int s = (src_y * cur_width) + src_x;
+  if (nodes[d] < -1)
+    return 0;
+  int mp = get_tile_weight (monptr, src_y, src_x, dest_y, dest_x);
+  int old_mp = nodes[d];
+  if (old_mp == -1 || old_mp > mp)
+    {
+      nodes[d] = nodes[s] + mp;
+      return 1;
+    }
+  return 0;
+}
+
+static int
+get_optimal_direction_towards_player (int monptr)
+{
+  int i;
+  size_t length = cur_width * cur_height * sizeof (int);
+  int *nodes = (int*) malloc (length);
+  memset (nodes, 0, length);
+  //step 1, populate node map
+  for (i = 0; i < cur_height * cur_width; i++)
+    {
+      cave_type *c_ptr = &cave[i / cur_width][i % cur_width];
+      inven_type *t_ptr = &t_list[c_ptr->tptr];
+      if (c_ptr->fval == BOUNDARY_WALL)
+        nodes[i] = -2; //can't go here.
+      else if (c_ptr->fval >= MIN_CLOSED_SPACE && !get_can_go_thru_walls (monptr))
+        nodes[i] = -2; //can't go here.
+      else if (c_ptr->fval <= MAX_OPEN_SPACE && !get_can_open_doors (monptr) && 
+               t_ptr->tval == TV_CLOSED_DOOR)
+        nodes[i] = -2; //can't go here.
+      else if (c_ptr->cptr > 1 && !get_can_eat_others (monptr))
+        nodes[i] = -2; //can't go here.
+      else
+        nodes[i] = -1; //can maybe go here.
+    }
+  //step 2, figure out how many steps it takes to get everywhere
+  // (and populate the rest of the node map)
+  struct pos_t *queue = NULL;
+  int queue_count = 0;
+  push (&queue, &queue_count, m_list[monptr].fy, m_list[monptr].fx);
+  while (queue_count)
+    {
+      int src_y, src_x, dest_y, dest_x;
+      pop (&queue, &queue_count, &src_y, &src_x);
+      for (dest_y = src_y - 1; dest_y <= src_y + 1; dest_y++)
+        {
+          if (dest_y < 0 || dest_y >= cur_height)
+            continue;
+          for (dest_x = src_x - 1; dest_x <= src_x + 1; dest_x++)
+            {
+              if ((dest_x < 0 || dest_x >= cur_width) || 
+                  (dest_y == src_y && dest_x == src_x))
+                continue;
+              if (calc_moves (nodes, monptr, src_y, src_x, dest_y, dest_x))
+                push (&queue, &queue_count, dest_y, dest_x);
+            }
+        }
+    }
+  //step 3 find the shortest path from monster to player
+  int dist = nodes[(char_row * cur_width) + char_col];
+  int x = char_col;
+  int y = char_row;
+  int min = dist;
+  int min_pos_y = y;
+  int min_pos_x = x;
+  while (dist > 0)
+    {
+      int dir_y, dir_x;
+      for (dir_y = -1; dir_y <= 1; dir_y++)
+        for (dir_x = -1; dir_x <= 1; dir_x++)
+          {
+            if (!dir_y && !dir_x)
+              continue;
+            y += dir_y;
+            x += dir_x;
+            if (y < 0 || y > cur_width || x < 0 || x > cur_height)
+              continue;
+            dist = nodes[(y * cur_width) + x];
+            if (dist >= 0 &&  dist < min)
+              {
+                min = dist;
+                min_pos_y = y;
+                min_pos_x = x;
+              }
+          }
+    }
+  free (queue);
+  free (nodes);
+}
 
 /* Move the critters about the dungeon			-RAK-	*/
 static void
@@ -1680,7 +1841,14 @@ mon_move (monptr, rcmove)
       /* Normal movement */
       else if (r_ptr->cmove & CM_MOVE_NORMAL)
 	{
-	  if (randint (200) == 1)
+          get_moves (monptr, mm);
+          int num = 200;
+          if (r_ptr->cmove & CM_MOVE_PERSIST)
+            {
+              mm[0] = get_optimal_direction_towards_player (monptr);
+              num = 100;
+            }
+	  if (randint (num) == 1)
 	    {
 	      mm[0] = randint (9);
 	      mm[1] = randint (9);
@@ -1688,8 +1856,6 @@ mon_move (monptr, rcmove)
 	      mm[3] = randint (9);
 	      mm[4] = randint (9);
 	    }
-	  else
-	    get_moves (monptr, mm);
 	  *rcmove |= CM_MOVE_NORMAL;
 	  make_move (monptr, mm, rcmove);
 	}
