@@ -95,7 +95,7 @@ extern cave_type cave[MAX_HEIGHT][MAX_WIDTH];
 
 /* Following are player variables				*/
 extern player_type py;
-extern char *player_title[MAX_CLASS][MAX_PLAYER_LEVEL];
+extern char *player_title[MAX_CLASS][2][MAX_PLAYER_LEVEL];
 extern race_type race[MAX_RACES];
 extern int background_start[MAX_RACES];
 extern background_type background[MAX_BACKGROUND];
@@ -456,6 +456,8 @@ void bash ();
 
 /* player.c */
 void fill_class_backpacks();
+int get_dungeon_item_index (int tval, int subval);
+int get_store_item_index (int tval, int subval);
 
 /* potions.c */
 void quaff ();
@@ -496,6 +498,7 @@ int set_null ();
 int set_acid_destroy ();
 int set_fire_destroy ();
 int set_large ();
+int set_book ();
 int general_store ();
 int armory ();
 int weaponsmith ();
@@ -552,6 +555,7 @@ void teleport_to ();
 int teleport_monster ();
 int mass_genocide ();
 int genocide ();
+int resist_poison_gas();
 int speed_monsters ();
 int sleep_monsters2 ();
 int mass_poly ();
@@ -620,6 +624,7 @@ int get_random_wand_effect_index();
 void wizard_light ();
 void change_character ();
 void wizard_create ();
+void wizard_simple_create ();
 
 /* call functions which expand tilde before calling open/fopen */
 #define open topen
