@@ -177,7 +177,8 @@ alloc_object (alloc_set, typ, num)
       /* don't put an object beneath the player, this could cause problems
          if player is standing under rubble, or on a trap */
       while ((!(*alloc_set) (cave[i][j].fval)) ||
-	     (cave[i][j].tptr != 0) || (i == char_row && j == char_col));
+	     (cave[i][j].tptr != 0) || (i == char_row && j == char_col) ||
+             (typ == 3 /*rubble */ && cave[i][j].cptr != 0));
       if (typ < 4)
 	{			/* typ == 2 not used, used to be visible traps */
 	  if (typ == 1)
@@ -258,7 +259,7 @@ void
 prt_stat (stat)
      int stat;
 {
-  stat_type out_val1;
+  vtype out_val1;
 
   cnv_stat (py.stats.use_stat[stat], out_val1, sizeof (out_val1));
   put_buffer (stat_names[stat], 6 + stat, STAT_COLUMN);
@@ -286,7 +287,7 @@ prt_lnum (header, num, row, column)
 {
   vtype out_val;
 
-  snprintf (out_val, sizeof (out_val), "%s: %6ld", header, num);
+  snprintf (out_val, sizeof (out_val), "%s: %6ld", header, (int)num);
   put_buffer (out_val, row, column);
 }
 
@@ -314,6 +315,18 @@ prt_num (header, num, row, column)
   snprintf (out_val, sizeof (out_val), "%s: %6d", header, num);
   put_buffer (out_val, row, column);
 }
+static void
+prt_num_pair (header, num, num2, row, column)
+     char *header;
+     int num, num2, row, column;
+{
+  vtype out_val;
+
+  char buf[32];
+  snprintf (buf, sizeof (buf), "%d/%d", num, num2);
+  snprintf (out_val, sizeof (out_val), "%s:%7s", header, buf);
+  put_buffer (out_val, row, column);
+}
 
 /* Print long number at given row, column */
 static void
@@ -455,7 +468,7 @@ title_string ()
   if (py.misc.lev < 1)
     p = "Babe in arms";
   else if (py.misc.lev <= MAX_PLAYER_LEVEL)
-    p = player_title[py.misc.pclass][py.misc.lev - 1];
+    p = player_title[py.misc.pclass][py.misc.male][py.misc.lev - 1];
   else if (py.misc.male)
     p = "**KING**";
   else
@@ -484,7 +497,7 @@ prt_level ()
 void
 prt_cmana ()
 {
-  prt_int (py.misc.cmana, 15, STAT_COLUMN + 6);
+  prt_num_pair ("MANA", py.misc.cmana, py.misc.mana, 15, STAT_COLUMN);
 }
 
 
@@ -492,7 +505,7 @@ prt_cmana ()
 void
 prt_mhp ()
 {
-  prt_int (py.misc.mhp, 16, STAT_COLUMN + 6);
+  prt_num_pair ("HP  ", py.misc.chp, py.misc.mhp, 16, STAT_COLUMN);
 }
 
 
@@ -500,7 +513,7 @@ prt_mhp ()
 void
 prt_chp ()
 {
-  prt_int (py.misc.chp, 17, STAT_COLUMN + 6);
+  prt_num_pair ("HP  ", py.misc.chp, py.misc.mhp, 16, STAT_COLUMN);
 }
 
 
@@ -997,9 +1010,9 @@ prt_stat_block ()
     prt_stat (i);
   prt_num ("LEV ", (int) m_ptr->lev, 13, STAT_COLUMN);
   prt_lnum ("EXP ", m_ptr->exp, 14, STAT_COLUMN);
-  prt_num ("MANA", m_ptr->cmana, 15, STAT_COLUMN);
-  prt_num ("MHP ", m_ptr->mhp, 16, STAT_COLUMN);
-  prt_num ("CHP ", m_ptr->chp, 17, STAT_COLUMN);
+  prt_num_pair ("MANA", m_ptr->cmana, m_ptr->mana, 15, STAT_COLUMN);
+  prt_num_pair ("HP  ", m_ptr->chp, m_ptr->mhp, 16, STAT_COLUMN);
+  //prt_num ("CHP ", m_ptr->chp, 17, STAT_COLUMN);
   prt_num ("AC  ", m_ptr->dis_ac, 19, STAT_COLUMN);
   prt_lnum ("GOLD", m_ptr->au, 20, STAT_COLUMN);
   prt_winner ();
@@ -1719,6 +1732,16 @@ get_spell (spell, num, sn, sc, prompt, first_spell)
 }
 
 
+static int
+count_spells_learned ()
+{
+  int i, num_spells_learned = 0;
+  for (i = 0; i < MAX_SPELLS; i++)
+    if (spell_status[i].learned)
+      num_spells_learned++;
+  return num_spells_learned;
+}
+
 /* calculate number of spells player should have, and learn forget spells
    until that number is met -JEW- */
 void
@@ -1805,6 +1828,8 @@ calc_spells (stat)
 	{
 	  // j is (i+1)th spell learned 
 	  j = spell_order[i];
+          if (j == MAX_SPELLS)
+            continue;
 	  if (spell_status[j].forgotten)
 	    {
 	      if (msp_ptr[j].slevel <= p_ptr->lev)
@@ -1844,15 +1869,18 @@ calc_spells (stat)
     }
   else if (new_spells < 0)
     {
+      int num_spells_learned = count_spells_learned ();
       /*forget spells until new_spells zero or no more spells known, spells
          are forgotten in the opposite order that they were learned */
-      for (i = MAX_SPELLS; new_spells; i--)
+      for (i = MAX_SPELLS - 1; new_spells && num_spells_learned; i--)
 	{
+          if (i < 0)
+           break;
 	  //j is the (i+1)th spell learned 
 	  j = spell_order[i];
 	  // shifting by amounts greater than number of bits in long gives
 	  // an undefined result, so don't shift for unknown spells 
-	  if (spell_status[j].learned)
+	  if (j < MAX_SPELLS && spell_status[j].learned)
 	    {
 	      spell_status[j].learned = 0;
 	      spell_status[j].forgotten = 1;
@@ -1971,7 +1999,8 @@ gain_spells ()
           if (spell_status[j].learned == 0 &&
               msp_ptr[j].slevel <= p_ptr->lev)
             {
-              if (stat == A_INT && has_spell_in_book(j, TV_MAGIC_BOOK))
+              if ((stat == A_INT && has_spell_in_book(j, TV_MAGIC_BOOK)) ||
+                  (stat == A_WIS && has_spell_in_book(j, TV_PRAYER_BOOK)))
                 {
                   spells[i] = j;
                   i++;
@@ -2001,7 +2030,7 @@ gain_spells ()
 	      if (j >= 0 && j < i && j < 22)
 		{
 		  new_spells--;
-                  spell_status[j].learned = 1;
+                  spell_status[spells[j]].learned = 1;
 		  spell_order[last_known++] = spells[j];
 		  for (; j <= i - 1; j++)
 		    spells[j] = spells[j + 1];
@@ -2020,7 +2049,7 @@ gain_spells ()
 	  while (new_spells)
 	    {
 	      j = randint (i) - 1;
-              spell_status[j].learned = 1;
+              spell_status[spells[j]].learned = 1;
 	      spell_order[last_known++] = spells[j];
 	      snprintf (tmp_str, sizeof (tmp_str),
 			"You have learned the prayer of %s.",
@@ -2053,10 +2082,7 @@ calc_mana (stat)
   register int32 value;
 
   p_ptr = &py.misc;
-  int i, num_spells_learned = 0;
-  for (i = 0; i < MAX_SPELLS; i++)
-    if (spell_status[i].learned)
-      num_spells_learned++;
+  int i, num_spells_learned = count_spells_learned ();
 
   if (num_spells_learned > 0)
     {
