@@ -231,7 +231,7 @@ disarm_trap ()
 	  i_ptr = &t_list[c_ptr->tptr];
 	  i = i_ptr->tval;
 	  level = i_ptr->level;
-	  if (i == TV_VIS_TRAP)	/* Floor trap    */
+	  if (i == TV_VIS_TRAP && i_ptr->subval > 0)	/* Floor trap    */
 	    {
 	      if ((tot + 100 - level) > randint (100))
 		{
@@ -256,6 +256,9 @@ disarm_trap ()
 		  py.flags.confused = 0;
 		  move_char (dir, FALSE);
 		  py.flags.confused += tmp;
+                  /* once the floor trap goes off, it's expired. 
+                     it can't go off twice! */
+	          t_list[c_ptr->tptr].subval = 0;
 		}
 	    }
 	  else if (i == TV_CHEST)
@@ -286,6 +289,9 @@ disarm_trap ()
 		      msg_print ("You set a trap off!");
 		      known2 (i_ptr);
 		      chest_trap (y, x);
+                      /* once the floor trap goes off, it's gone.
+                       it can't go off twice! */
+                      i_ptr->flags &= ~CH_TRAPPED;
 		    }
 		}
 	      else
