@@ -35,31 +35,6 @@ int16u player_hp[MAX_PLAYER_LEVEL];
 int32u spell_order[MAX_SPELLS];
 spell_status_type spell_status[MAX_SPELLS];
 
-
-char *spell_names[2][MAX_SPELLS] = {
-  {
-  /* Mage Spells */
-  "Magic Missile", "Detect Monsters", "Phase Door", "Light Area",
-  "Cure Light Wounds", "Find Hidden Traps/Doors", "Stinking Cloud",
-  "Confusion", "Lightning Bolt", "Trap/Door Destruction", "Sleep I",
-  "Cure Poison", "Teleport Self", "Remove Curse", "Frost Bolt",
-  "Turn Stone to Mud", "Create Food", "Recharge Item I", "Sleep II",
-  "Polymorph Other", "Identify", "Sleep III", "Fire Bolt", "Slow Monster",
-  "Frost Ball", "Recharge Item II", "Teleport Other", "Haste Self",
-  "Fire Ball", "Word of Destruction", "Genocide",
-  }, {
-  /* Priest Spells, start at index 31 */
-  "Detect Evil", "Cure Light Wounds", "Bless", "Remove Fear", "Call Light",
-  "Find Traps", "Detect Doors/Stairs", "Slow Poison", "Blind Creature",
-  "Portal", "Cure Medium Wounds", "Chant", "Sanctuary", "Create Food",
-  "Remove Curse", "Resist Heat and Cold", "Neutralize Poison",
-  "Orb of Draining", "Cure Serious Wounds", "Sense Invisible",
-  "Protection from Evil", "Earthquake", "Sense Surroundings",
-  "Cure Critical Wounds", "Turn Undead", "Prayer", "Dispel Undead",
-  "Heal", "Dispel Evil", "Glyph of Warding", "Holy Word"
-  }
-};
-
 /* Each type of character starts out with a few provisions.	*/
 /* Note that the entries refer to elements of the object_list[] array*/
 /* 344 = Food Ration, 365 = Wooden Torch, 123 = Cloak, 318 = Beginners-Majik,
@@ -67,7 +42,8 @@ char *spell_names[2][MAX_SPELLS] = {
    see fill_class_backpacks */
 int16u player_init[MAX_CLASS][MAX_DEFAULT_PACK_ITEMS];
 
-int get_store_item_index(int tval, int subval)
+int 
+get_store_item_index (int tval, int subval)
 {
   int i;
   for (i = MAX_DUNGEON_OBJ; i < OBJ_OPEN_DOOR; i++)
@@ -78,7 +54,8 @@ int get_store_item_index(int tval, int subval)
   return -1;
 }
 
-int get_dungeon_item_index(int tval, int subval)
+int
+get_dungeon_item_index (int tval, int subval)
 {
   int i;
   for (i = 0; i < MAX_DUNGEON_OBJ; i++)
@@ -89,13 +66,14 @@ int get_dungeon_item_index(int tval, int subval)
   return -1;
 }
 
-void fill_class_backpacks()
+void
+fill_class_backpacks ()
 {
   int i;
   for (i = 0; i < MAX_CLASS; i++)
     {
       player_init[i][0] = get_store_item_index(TV_FOOD, 90);
-      if (player_init[i][0] == -1)
+      if (player_init[i][0] == 65535)
         {
           restore_term();
           fprintf (stderr, "Error! "
@@ -104,7 +82,7 @@ void fill_class_backpacks()
           exit(1);
         }
       player_init[i][1] = get_store_item_index(TV_LIGHT, 192);
-      if (player_init[i][1] == -1)
+      if (player_init[i][1] == 65535)
         {
           restore_term();
           fprintf (stderr, "Error! "
@@ -113,7 +91,7 @@ void fill_class_backpacks()
           exit(1);
         }
       player_init[i][2] = get_dungeon_item_index(TV_CLOAK, 1);
-      if (player_init[i][2] == -1)
+      if (player_init[i][2] == 65535)
         {
           restore_term();
           fprintf (stderr, "Error! "
@@ -122,7 +100,7 @@ void fill_class_backpacks()
           exit(1);
         }
       player_init[i][3] = get_dungeon_item_index(TV_SWORD, 3);
-      if (player_init[i][3] == -1)
+      if (player_init[i][3] == 65535)
         {
           restore_term();
           fprintf (stderr, "Error! "
@@ -133,7 +111,7 @@ void fill_class_backpacks()
       if (class[i].spell == NONE)
         {
           player_init[i][4] = get_dungeon_item_index(TV_SOFT_ARMOR, 2);
-          if (player_init[i][4] == -1)
+          if (player_init[i][4] == 65535)
             {
               restore_term();
               fprintf (stderr, "Error! "
@@ -145,7 +123,7 @@ void fill_class_backpacks()
       else if (class[i].spell == MAGE)
         {
           player_init[i][4] = get_dungeon_item_index(TV_MAGIC_BOOK, 64);
-          if (player_init[i][4] == -1)
+          if (player_init[i][4] == 65535)
             {
               restore_term();
               fprintf (stderr, "Error! "
@@ -158,7 +136,7 @@ void fill_class_backpacks()
         {
           player_init[i][4] = 322;
           player_init[i][4] = get_dungeon_item_index(TV_PRAYER_BOOK, 64);
-          if (player_init[i][4] == -1)
+          if (player_init[i][4] == 65535)
             {
               fprintf (stderr, "Error! Can't"
                        " find a TV_PRAYER_BOOK item of subval 64 (%s)%s.\n",
